@@ -1,9 +1,9 @@
-cpt.mean=function(data,penalty="MBIC",pen.value=0,method="AMOC",Q=5,test.stat="Normal",class=TRUE,param.estimates=TRUE,minseglen=1){
+cpt.mean=function(data,penalty="MBIC",pen.value=0,method="PELT",Q=5,test.stat="Normal",class=TRUE,param.estimates=TRUE,minseglen=1){
   checkData(data)
   if(method=="SegNeigh" & minseglen>1){stop("minseglen not yet implemented for SegNeigh method, use PELT instead.")}
   if(minseglen<1){minseglen=1;warning('Minimum segment length for a change in mean is 1, automatically changed to be 1.')}
   if(!((test.stat=="Normal")||(test.stat=="CUSUM"))){ stop("Invalid test statistic, must be Normal or CUSUM") }
-  
+
   if(penalty == "CROPS"){
     # browser()
     if(is.numeric(pen.value)){
@@ -20,30 +20,33 @@ cpt.mean=function(data,penalty="MBIC",pen.value=0,method="AMOC",Q=5,test.stat="N
       stop('For CROPS, pen.value must be supplied as a numeric vector and must be of length 2')
     }
   }
-  
+
   if(test.stat=="Normal"){
     if(method=="AMOC"){
       return(single.mean.norm(data,penalty,pen.value,class,param.estimates,minseglen))
     }
     else if(method=="PELT" || method=="BinSeg"){
-      
-      return(multiple.mean.norm(data,mul.method=method,penalty,pen.value,Q,class,param.estimates,minseglen)) 
+
+      return(multiple.mean.norm(data,mul.method=method,penalty,pen.value,Q,class,param.estimates,minseglen))
     }
     else if(method=="SegNeigh"){
       warning("SegNeigh is computationally slow, use PELT instead")
       return(multiple.mean.norm(data,mul.method=method,penalty,pen.value,Q,class,param.estimates,minseglen))
-    }	
+    }
     else{
       stop("Invalid Method, must be AMOC, PELT, SegNeigh or BinSeg")
     }
   }
   else if(test.stat=="CUSUM"){
-    warning('Traditional penalty values are not appropriate for the CUSUM test statistic')
     if(method=="AMOC"){
-      return(single.mean.cusum(data,penalty,pen.value,class,param.estimates,minseglen))
+      tmp=single.mean.cusum(data,penalty,pen.value,class,param.estimates,minseglen)
+      warning('Traditional penalty values are not appropriate for the CUSUM test statistic')
+      return(tmp)
     }
     else if(method=="SegNeigh" || method=="BinSeg"){
-      return(multiple.mean.cusum(data,mul.method=method,penalty,pen.value,Q,class,param.estimates,minseglen))
+      tmp=multiple.mean.cusum(data,mul.method=method,penalty,pen.value,Q,class,param.estimates,minseglen)
+      warning('Traditional penalty values are not appropriate for the CUSUM test statistic')
+      return(tmp)
     }
     else{
       stop("Invalid Method, must be AMOC, SegNeigh or BinSeg")
@@ -68,7 +71,7 @@ cpt.mean=function(data,penalty="MBIC",pen.value=0,method="AMOC",Q=5,test.stat="N
 #	}
 #}
 
-cpt.var=function(data,penalty="MBIC",pen.value=0,know.mean=FALSE, mu=NA,method="AMOC",Q=5,test.stat="Normal",class=TRUE,param.estimates=TRUE,minseglen=2){
+cpt.var=function(data,penalty="MBIC",pen.value=0,know.mean=FALSE, mu=NA,method="PELT",Q=5,test.stat="Normal",class=TRUE,param.estimates=TRUE,minseglen=2){
   checkData(data)
   if(method=="SegNeigh" & minseglen>2){stop("minseglen not yet implemented for SegNeigh method, use PELT instead.")}
   if(minseglen<2){minseglen=2;warning('Minimum segment length for a change in variance is 2, automatically changed to be 2.')}
@@ -88,14 +91,14 @@ cpt.var=function(data,penalty="MBIC",pen.value=0,know.mean=FALSE, mu=NA,method="
       stop('For CROPS, pen.value must be supplied as a numeric vector and must be of length 2')
     }
   }
-  
+
   if(test.stat =="Normal"){
-    
+
     if(method=="AMOC"){
       return(single.var.norm(data,penalty,pen.value,know.mean,mu,class,param.estimates,minseglen))
     }
     else if(method=="PELT" || method=="BinSeg"){
-      
+
       return(multiple.var.norm(data,mul.method=method,penalty,pen.value,Q,know.mean,mu,class,param.estimates,minseglen))
     }
     else if(method=="SegNeigh"){
@@ -123,13 +126,13 @@ cpt.var=function(data,penalty="MBIC",pen.value=0,know.mean=FALSE, mu=NA,method="
   }
 }
 
-cpt.meanvar=function(data,penalty="MBIC",pen.value=0,method="AMOC",Q=5,test.stat="Normal",class=TRUE,param.estimates=TRUE,shape=1,minseglen=2){
+cpt.meanvar=function(data,penalty="MBIC",pen.value=0,method="PELT",Q=5,test.stat="Normal",class=TRUE,param.estimates=TRUE,shape=1,minseglen=2){
   checkData(data)
   if(method=="SegNeigh" & minseglen>2){stop("minseglen not yet implemented for SegNeigh method, use PELT instead.")}
   if(minseglen<2){
     if(!(minseglen==1 & (test.stat=="Poisson"|test.stat=="Exponential"))){
       minseglen=2;warning('Minimum segment length for a change in mean and variance is 2, automatically changed to be 2.')}
-    }
+  }
   if(penalty == "CROPS"){
     if(is.numeric(pen.value)){
       if(length(pen.value) == 2){
@@ -146,12 +149,12 @@ cpt.meanvar=function(data,penalty="MBIC",pen.value=0,method="AMOC",Q=5,test.stat
     }
   }
   if(test.stat=="Normal"){
-    
+
     if(method=="AMOC"){
       return(single.meanvar.norm(data,penalty,pen.value,class,param.estimates,minseglen))
     }
     else if(method=="PELT" || method=="BinSeg"){
-      
+
       return(multiple.meanvar.norm(data,mul.method=method,penalty,pen.value,Q,class,param.estimates,minseglen))
     }
     else if(method=="SegNeigh"){
@@ -182,7 +185,7 @@ cpt.meanvar=function(data,penalty="MBIC",pen.value=0,method="AMOC",Q=5,test.stat
       return(single.meanvar.exp(data,penalty,pen.value,class,param.estimates,minseglen))
     }
     else if(method=="PELT" || method=="BinSeg"){
-      
+
       return(multiple.meanvar.exp(data,mul.method=method,penalty,pen.value,Q,class,param.estimates,minseglen))
     }
     else if(method=="SegNeigh"){
@@ -198,7 +201,7 @@ cpt.meanvar=function(data,penalty="MBIC",pen.value=0,method="AMOC",Q=5,test.stat
       return(single.meanvar.poisson(data,penalty,pen.value,class,param.estimates,minseglen))
     }
     else if(method=="PELT" || method=="BinSeg"){
-      
+
       return(multiple.meanvar.poisson(data,mul.method=method,penalty,pen.value,Q,class,param.estimates,minseglen))
     }
     else if(method=="SegNeigh"){
@@ -217,7 +220,7 @@ cpt.meanvar=function(data,penalty="MBIC",pen.value=0,method="AMOC",Q=5,test.stat
 checkData = function(data){
   if(!is.numeric(data)){
     stop("Only numeric data allowed")
-  }  
+  }
   if(anyNA(data)){stop("Missing value: NA is not allowed in the data as changepoint methods are only sensible for regularly spaced data.")}
-  
+
 }
